==> matplot2tikz-0.1.0.tar.gz: matplot2tikz-0.1.0/doc/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

import datetime
import pathlib

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
from configparser import ConfigParser

# Sphinx 1.* compat (for readthedocs)
master_doc = "index"

p = ConfigParser()
this_dir = pathlib.Path(__file__).resolve().parent
p.read(this_dir / ".." / "setup.cfg")

# -- Project information -----------------------------------------------------
project = p["metadata"]["name"]
year = datetime.datetime.utcnow().year
author = p["metadata"]["author"]
copyright = f"2010-{year}, {author}"

release = p["metadata"]["version"]


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ["sphinx.ext.autodoc"]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "alabaster"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ["_static"]

html_theme_options = {
    # "logo": "meshplex-logo.svg",
    "github_repo": "matplot2tikz",
    "github_banner": True,
    "github_button": False,
}

==> matplot2tikz-0.3.0.tar.gz: matplot2tikz-0.3.0/doc/conf.py <==
# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

import datetime
import pathlib
from typing import List

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
from configparser import ConfigParser

# Sphinx 1.* compat (for readthedocs)
master_doc = "index"

p = ConfigParser()
this_dir = pathlib.Path(__file__).resolve().parent
p.read(this_dir / ".." / "setup.cfg")

# -- Project information -----------------------------------------------------
project = p["metadata"]["name"]
year = datetime.datetime.utcnow().year
author = p["metadata"]["author"]
copyright = f"2010-{year}, {author}"

release = p["metadata"]["version"]


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ["sphinx.ext.autodoc"]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns: List[str] = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "alabaster"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ["_static"]

html_theme_options = {
    # "logo": "meshplex-logo.svg",
    "github_repo": "matplot2tikz",
    "github_banner": True,
    "github_button": False,
}
